@@ -49,7 +49,7 @@ class Handler(HandlerBase):
                 Message.SPECIFICATION.name
             ]
 
-            command = "grep -E '^{\"message_keyword\":\""
+            command = "grep -E '^\\{\"message_keyword\":\""
             command = f"{command}({'|'.join(message_types)})\""
             command += ".+,\"test_name\":\"%s.*?\",'" % name.replace("'", r"'\''")
             steps = [
@@ -62,4 +62,4 @@ class Handler(HandlerBase):
             super(Handler.Pipeline, self).__init__(steps, stop=stop_event)
 
     def handle(self, args):
-        self.Pipeline(args.name, args.log, args.output, tail=True).run()
\ No newline at end of file
+        self.Pipeline(args.name, args.log, args.output, tail=True).run()
