@@ -18,6 +18,7 @@ import time
 import inspect
 import importlib
 import builtins
+import itertools
 import functools
 import textwrap
 import pkgutil
@@ -422,3 +423,37 @@ def current_time(test=None):
     else:
        return test.test_time
 
+def aslice(iterator, *args, **kwargs):
+    """Return an iterator whose next() method returns
+    a slice that only contains selected  values from an iterable.
+
+    aslice(iterable, stop)
+    aslice(iterable, start, stop[, step])
+
+    > If start is specified, will skip all preceding elements;
+    > otherwise, start defaults to zero.  Step defaults to one.  If
+    > specified as another value, step determines how many values are
+    > skipped between successive calls.  Works like a slice() on a list
+    > but returns an iterator.
+
+    This is just a wrapper for itertools.islice standard library function.
+
+    :returns: islice object
+    """
+    return itertools.islice(iterator, *args, **kwargs)
+
+def chunks(iterator, n):
+    """Converts iterator into an iterable over sub-iterables
+    chunks with n elements each.
+
+    :param n: chunk size
+    """
+    while True:
+        try:
+            chunk = list()
+            for _ in range(n):
+                chunk.append(next(iterator))
+        except StopIteration:
+            break
+        finally:
+            yield chunk
\ No newline at end of file
